# API Reference

## AuthService

::: pico_auth.service.AuthService

## JWTProvider

::: pico_auth.jwt_provider.JWTProvider

## PasswordService

::: pico_auth.passwords.PasswordService

## UserRepository

::: pico_auth.repository.UserRepository

## RefreshTokenRepository

::: pico_auth.repository.RefreshTokenRepository

## AuthSettings

::: pico_auth.config.AuthSettings

## Models

::: pico_auth.models.User

::: pico_auth.models.RefreshToken

## Errors

::: pico_auth.errors.AuthError

::: pico_auth.errors.UserExistsError

::: pico_auth.errors.InvalidCredentialsError

::: pico_auth.errors.TokenExpiredError

::: pico_auth.errors.TokenInvalidError

::: pico_auth.errors.UserNotFoundError

::: pico_auth.errors.InsufficientPermissionsError

::: pico_auth.errors.UserSuspendedError
